@@ -24,7 +24,7 @@ from ipywidgets.widgets import (
 from geoapps.base import BaseApplication
 from geoapps.plotting import PlotSelection2D
 from geoapps.utils import find_value, geophysical_systems, string_2_list
-from geoapps.selection import ObjectDataSelection, LineOptions
+from geoapps.selection import ObjectDataSelection, LineOptions, TopographyOptions
 
 
 class ChannelOptions:
@@ -119,60 +119,7 @@ class SensorOptions(ObjectDataSelection):
 
         self._data.description = "Radar (Optional):"
         self._data.style = {"description_width": "initial"}
-        self.update_data_list()
-
-    @property
-    def offset(self):
-        return self._offset
-
-    @property
-    def options(self):
-        return self._options
-
-    def update_options(self):
-        self._widget.children = [
-            self.options,
-            self.option_list[self.options.value],
-        ]
-
-
-class TopographyOptions(ObjectDataSelection):
-    """
-    Define the topography used by the inversion
-    """
-
-    def __init__(self, **kwargs):
-        self.find_label = ["topo", "dem", "dtm", "elevation", "Z"]
-        self._offset = FloatText(description="Vertical offset (+ve up)")
-        self._constant = FloatText(description="Elevation (m)",)
-
-        super().__init__(**kwargs)
-
-        self.objects.value = find_value(self.objects.options, self.find_label)
-        self.option_list = {
-            "Object": self.widget,
-            "Relative to Sensor": self.offset,
-            "Constant": self.constant,
-            "None": widgets.Label("No topography"),
-        }
-        self._options = widgets.RadioButtons(
-            options=["Object", "Relative to Sensor", "Constant"],
-            description="Define by:",
-        )
-
-        def update_options(_):
-            self.update_options()
-
-        self.options.observe(update_options)
-        self._widget = VBox([self.options, self.option_list[self.options.value]])
-
-    @property
-    def panel(self):
-        return self._panel
-
-    @property
-    def constant(self):
-        return self._constant
+        self.update_data_list(None)
 
     @property
     def offset(self):
@@ -487,11 +434,6 @@ class InversionOptions(BaseApplication):
             continuous_update=False,
         )
 
-        # def check_max_iterations(_):
-        #     self.check_max_iterations()
-        #
-        # self._norms.observe(check_max_iterations)
-
         self._mesh = MeshOctreeOptions()
         self.inversion_options = {
             "output name": self._output_name,
@@ -532,25 +474,9 @@ class InversionOptions(BaseApplication):
             layout=Layout(width="100%"),
         )
 
-        # model_list = []
-        # for obj in self.workspace.all_objects():
-        #     if isinstance(obj, (BlockModel, Octree, Surface)):
-        #         for data in obj.children:
-        #             if (
-        #                 getattr(data, "values", None) is not None
-        #                 and data.name != "Visual Parameters"
-        #             ):
-        #                 model_list += [data.name]
-        #
-
-    # def check_max_iterations(self):
-    #     try:
-    #         if all([val == 2 for val in string_2_list(self._norms.value)]):
-    #             self._max_iterations.value = 10
-    #
-    #     except:
-    #         print("Check values of norms. There should be 4 values between [0, 2]")
-    #         self._norms.value = "0, 2, 2, 2"
+        for obj in self.__dict__:
+            if hasattr(getattr(self, obj), "style"):
+                getattr(self, obj).style = {"description_width": "initial"}
 
     def inversion_option_change(self):
         self._widget.children[1].children = [
@@ -761,9 +687,10 @@ class InversionApp(PlotSelection2D):
             "height": 1500.0,
             "azimuth": -20,
         },
-        "inversion_parameters": {"norms": "0, 2, 2, 2"},
+        "inversion_parameters": {"norms": "0, 2, 2, 2", "max_iterations": 20},
         "topography": {"objects": "Topography", "data": "elevation"},
         "sensor": {"offset": "0, 0, 40", "options": "topo + radar + (dx, dy, dz)"},
+        "padding_distance": "1000, 1000, 1000, 1000, 0, 0",
     }
 
     def __init__(self, **kwargs):
@@ -825,6 +752,8 @@ class InversionApp(PlotSelection2D):
         #                 val.observe(update_options)
 
         # self.plot_widget.layout = Layout(width="60%")
+        self.mesh_octree = MeshOctreeOptions(**kwargs)
+        self.mesh_1D = Mesh1DOptions(**kwargs)
 
         super().__init__(**kwargs)
 
@@ -842,8 +771,6 @@ class InversionApp(PlotSelection2D):
             self.data_channel_choices_observer()
 
         self.data_channel_choices.observe(data_channel_choices_observer, names="value")
-        self.mesh_octree = MeshOctreeOptions(**kwargs)
-        self.mesh_1D = Mesh1DOptions(**kwargs)
 
         # Define widgets linked to common object
         self.topography = TopographyOptions()
@@ -857,16 +784,14 @@ class InversionApp(PlotSelection2D):
             self.inversion_parameters.__populate__(**kwargs["inversion_parameters"])
 
         self.sensor = SensorOptions()
-        self.sensor._objects = self._objects
         self.sensor.workspace = self._workspace
+        self.sensor.objects = self.objects
         if "sensor" in kwargs.keys():
             self.sensor.__populate__(**kwargs["sensor"])
 
         self.lines = LineOptions()
-        self.lines._objects = self._objects
         self.lines.workspace = self._workspace
-
-        # self.__populate__()
+        self.lines.objects = self.objects
 
         def update_selection(_):
             self.update_selection()
@@ -1248,9 +1173,9 @@ class InversionApp(PlotSelection2D):
         if self.workspace.get_entity(self.objects.value):
             obj = self.workspace.get_entity(self.objects.value)[0]
             data_list = obj.get_data_list()
-            self.sensor.update_data_list()
-            self.lines.update_data_list()
-            self.lines.update_line_list()
+            self.sensor.update_data_list(None)
+            self.lines.update_data_list(None)
+            self.lines.update_line_list(None)
 
             for aem_system, specs in self.em_system_specs.items():
                 if any([specs["flag"] in channel for channel in data_list]):
